starfish.metadata package
=========================

Submodules
----------

.. toctree::

   starfish.metadata.metadata

Module contents
---------------

.. automodule:: starfish.metadata
   :members:
   :undoc-members:
   :show-inheritance:
